# Tests by default. No tests: rpm -ba --define 'dotests 0' *.spec
%{!?dotests: %define dotests 0}

%global __tar /opt/freeware/bin/tar
%global _libdir64 %{_prefix}/lib64
%global name lightgbm 
%global version 4.0.0
%global release 1

#python releated configs
%global py_major 3.9
%global py_minor 18

%global python_major python%{py_major}

%global python3_sitearch %(%{python_major} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(0))")
%global python3_sitearch64 %(%{python_major} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")

Name:           %{name}
Version:        %{version}
Release:        1
Summary:        Light Gradient Boosting Machine
License:        MIT
URL:            https://github.com/microsoft/LightGBM
Source0:        https://github.com/microsoft/LightGBM/archive/refs/tags/v%{version}.tar.gz
Source1:        https://github.com/lemire/fast_double_parser/archive/refs/tags/v0.3.0.tar.gz 
Source2:        https://github.com/fmtlib/fmt/archive/refs/tags/8.1.1.tar.gz
Source3:        https://gitlab.com/libeigen/eigen/-/archive/bb51d9f4fa3cf1114348b9180640d6da7d3964f9/eigen-bb51d9f4fa3cf1114348b9180640d6da7d3964f9.tar.gz
Source4:        ifaddrs.h
Source5:        getifaddrs.cpp

Patch0:         lightgbm-4.0.0-cmakelists.patch
Patch1:         lightgbm-4.0.0-socket_wrapper.patch
Patch2:         lightgbm-4.0.0-python-lib-loading.patch
Patch3: 	lightgbm-4.0.0-build-python.patch

BuildRequires:  gcc >= 10
BuildRequires:  gcc-c++ >= 10
BuildRequires:  cmake >= 3.26.4
BuildRequires:  gtest-devel >= 1.14.0

Requires: 	libgomp >= 10
Requires: 	libstdc++ >= 10
Requires: 	libgcc >= 10

%description
LightGBM is a  fast, distributed, high performance gradient boosting (GBT, GBDT, GBRT, GBM or MART) framework based on decision tree algorithms, 
used for ranking, classification and many other machine learning tasks.

It is a gradient boosting framework that uses tree based learning algorithms. It is designed to be distributed and efficient with the following advantages:

Faster training speed and higher efficiency.
Lower memory usage.
Better accuracy.
Support of parallel, distributed, and GPU learning.
Capable of handling large-scale data.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
Development headers for %{name}.


%package python3
Summary:        LightGBM Python Package
Group:          Development/Libraries/Python

BuildRequires:  %{python_major}-devel >= %{py_major}.%{py_minor}
BuildRequires:  %{python_major}-setuptools >= 65.2.0
Requires:       %{python_major} >= %{py_major}.%{py_minor}
Requires:       %{python_major}-numpy >= 1.21.2
Requires:       %{python_major}-scipy >= 1.7.1

%description python3
This package contains the Python 3 bindings for LightGBM.

%prep
%setup -n  LightGBM-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%{__tar} -xvf %{SOURCE1}  --strip 1 -C external_libs/fast_double_parser
%{__tar} -xvf %{SOURCE2}  --strip 1 -C external_libs/fmt
%{__tar} -xvf %{SOURCE3}  --strip 1 -C external_libs/eigen
cp %{SOURCE4} %{_builddir}/LightGBM-%{version}/include/LightGBM/ifaddrs.h
cp %{SOURCE5} %{_builddir}/LightGBM-%{version}/src/network/getifaddrs.cpp

%build
#64bit Build only
export OBJECT_MODE=64
export CC="gcc -maix64 -pthread -maltivec -mvsx "
export CFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include -fno-extern-tls-init"
export CXX="g++ -maix64 -pthread -maltivec -mvsx "
export CXXFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include -fno-extern-tls-init"
export LDFLAGS="-Wl,-bbigtoc"

cmake . -B build \
  -DBUILD_CPP_TEST=ON \
  -DBUILD_SHARED_LIBS=ON \
  -DCMAKE_INSTALL_PREFIX=%{_prefix}

cmake --build build -j 4

%install
export DESTDIR=$RPM_BUILD_ROOT
cmake  --install build
/usr/bin/strip -X64 $RPM_BUILD_ROOT%{_prefix}/bin/lightgbm

#python installation
export OBJECT_MODE=64
export CC="gcc -maix64 -pthread -maltivec -mvsx "
export CFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include -fno-extern-tls-init"
export CXX="g++ -maix64 -pthread -maltivec -mvsx "
export CXXFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include -fno-extern-tls-init"
export LDFLAGS="-Wl,-bbigtoc"

./build-python.sh
cd lightgbm-python 
%{python_major} -m pip install . --root %{buildroot} -vvv -I --no-deps 
cd ..
mkdir ${RPM_BUILD_ROOT}/%{python3_sitearch64}/lightgbm/lib
cp lib_lightgbm.a ${RPM_BUILD_ROOT}/%{python3_sitearch64}/lightgbm/lib/.

#Remove ifaddrs.h 
rm ${RPM_BUILD_ROOT}/%{_includedir}/LightGBM/ifaddrs.h

%check
export LIBPATH=/opt/freeware/lib/pthread:/opt/freeware/lib64:/opt/freeware/lib
cp testlightgbm build/.
cd build
./testlightgbm || true

%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(-,root,system,-)
%doc README.md LICENSE VERSION.txt
%{_libdir}/*.a
%{_bindir}/*

%files devel
%defattr(-,root,system,-)
%doc docs/*
%{_includedir}/LightGBM/

%files python3
%defattr(-,root,system,-)
%doc README.md LICENSE VERSION.txt
%{python3_sitearch64}/*

%changelog
* Tue Sep 26 2023 Ranjit Ranjan <ranjit.ranjan@ibm.com> - 4.0.0-1
- Port on AIX.
